@@ -1,7 +1,7 @@
 package bigint;
-use 5.005;
+use 5.006002;
 
-$VERSION = '0.08';
+$VERSION = '0.09';
 use Exporter;
 @ISA		= qw( Exporter );
 @EXPORT_OK	= qw( ); 
@@ -335,12 +335,12 @@ notation, though.
 
 =item inf()
 
-A shortcut to return Math::BigInt->binf(). Usefull because Perl does not always
+A shortcut to return Math::BigInt->binf(). Useful because Perl does not always
 handle bareword C<inf> properly.
 
 =item NaN()
 
-A shortcut to return Math::BigInt->bnan(). Usefull because Perl does not always
+A shortcut to return Math::BigInt->bnan(). Useful because Perl does not always
 handle bareword C<NaN> properly.
 
 =item upgrade()
@@ -369,7 +369,7 @@ following work:
 	print $x + 1, " ", $y,"\n";	# prints 10 9
 
 but calling any method that modifies the number directly will result in
-B<both> the original and the copy beeing destroyed:
+B<both> the original and the copy being destroyed:
 	
 	$x = 9; $y = $x;
 	print $x->badd(1), " ", $y,"\n";	# prints 10 10
